from setuptools import setup


def read_files(files):
    data = []
    for file in files:
        with open(file) as f:
            data.append(f.read())
    return "\n".join(data)


meta = {}
with open('idcloud/version.py', encoding='utf-8') as f:
    exec(f.read(), meta)

setup(
    name='idcloud-python',
    version=meta['__version__'],
    packages=[
        'idcloud',
        'idcloud.resources',
        'idcloud.enums',
        'idcloud.responses',
    ],
    install_requires=[
        'python-dotenv==0.18.*',
        'requests==2.26.*',
        'pyjwt==2.1.*'
    ],
    url='https://github.com/idcloud-python',
    license='MIT',
    author='Backbone s.r.o.',
    author_email='office@backbone.sk',
    description='API Client communicating with THALES IdCloud REST API.',
    long_description=read_files(['README.md', 'CHANGELOG.md']),
    long_description_content_type='text/markdown',
    classifiers=[
        # As from https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Topic :: Database',
        'Topic :: Security'
    ]
)
